@@ -23,7 +23,7 @@
 #include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
 #include "kcharselectdia.h"
-#include "config-kcharselect.h"
+#include <config-kcharselect.h>
 
 int main(int argc, char **argv)
 {
@@ -42,24 +42,24 @@ int main(int argc, char **argv)
   migrate.setUiFiles(QStringList() << QLatin1String("kcharselectui.rc"));
   migrate.migrate();
 
-  KAboutData aboutData( "kcharselect", i18n("KCharSelect"),
-    KCHARSELECT_VERSION, i18n("KDE character selection utility"), KAboutLicense::GPL,
-    QString(), i18n("A wrapper around the KCharSelect widget."), "http://utils.kde.org/projects/kcharselect" );
+  KAboutData aboutData( QStringLiteral("kcharselect"), i18n("KCharSelect"),
+    QLatin1String(KCHARSELECT_VERSION), i18n("KDE character selection utility"), KAboutLicense::GPL,
+    QString(), i18n("A wrapper around the KCharSelect widget."), QStringLiteral("http://utils.kde.org/projects/kcharselect") );
 
-  aboutData.addAuthor(i18n("Christoph Feck"), i18n("KF5 port and current maintainer"), "cfeck@kde.org");
-  aboutData.addAuthor(i18n("Daniel Laidig"), i18n("Author and previous maintainer"), "d.laidig@gmx.de" );
-  aboutData.addAuthor(i18n("Reginald Stadlbauer"), i18n("Author"), "reggie@kde.org");
+  aboutData.addAuthor(i18n("Christoph Feck"), i18n("KF5 port and current maintainer"), QStringLiteral("cfeck@kde.org"));
+  aboutData.addAuthor(i18n("Daniel Laidig"), i18n("Author and previous maintainer"), QStringLiteral("d.laidig@gmx.de") );
+  aboutData.addAuthor(i18n("Reginald Stadlbauer"), i18n("Author"), QStringLiteral("reggie@kde.org"));
 
   aboutData.addCredit( i18n("Daniel Laidig"), i18n("New GUI, Unicode information, incremental search,"
-        " and general improvements"), "d.laidig@gmx.de" );
-  aboutData.addCredit( i18n("Laurent Montel"), i18n("Porting help"), "montel@kde.org" );
-  aboutData.addCredit( i18n("Constantin Berzan"), i18n("Previous maintainer"), "exit3219@gmail.com" );
+        " and general improvements"), QStringLiteral("d.laidig@gmx.de") );
+  aboutData.addCredit( i18n("Laurent Montel"), i18n("Porting help"), QStringLiteral("montel@kde.org") );
+  aboutData.addCredit( i18n("Constantin Berzan"), i18n("Previous maintainer"), QStringLiteral("exit3219@gmail.com") );
   aboutData.addCredit( i18n("Nadeem Hasan"), i18n( "GUI cleanup and fixes" ),
-        "nhasan@kde.org" );
+        QStringLiteral("nhasan@kde.org") );
   aboutData.addCredit( i18n("Ryan Cumming"), i18n( "GUI cleanup and fixes" ),
-        "bodnar42@phalynx.dhs.org" );
+        QStringLiteral("bodnar42@phalynx.dhs.org") );
   aboutData.addCredit( i18n("Benjamin C. Meyer"), i18n("XMLUI conversion"),
-        "ben+kcharselect@meyerhome.net" );
+        QStringLiteral("ben+kcharselect@meyerhome.net" ));
   aboutData.addCredit( i18n("Bryce Nesbitt"), i18n("RTL support") );
 
   KAboutData::setApplicationData( aboutData );
